@@ -1,14 +1,20 @@
 #' @title Plot BANTER Detector Traces
-#' @description Plot traces of OOB error rates for detector Random Forest models
+#' @description Plot traces of OOB error rates for detector Random Forest 
+#'   models.
 #' 
 #' @param x a \code{\link{banter_model}} object.
-#' @param detector names of models to plot. If set to \code{NULL}, traces for all
-#'   models will be shown.
+#' @param detector names of models to plot. If set to \code{NULL}, traces for 
+#'   all models will be shown.
 #' 
-#' @seealso \code{\link[rfPermute]{plotRFtrace}}
+#' @seealso \code{\link[rfPermute]{plotTrace}}
 #'
 #' @author Eric Archer \email{eric.archer@@noaa.gov}
 #' 
+#' @references Rankin, S. , Archer, F. , Keating, J. L., Oswald, J. N., 
+#'   Oswald, M. , Curtis, A. and Barlow, J. (2017), Acoustic classification 
+#'   of dolphins in the California Current using whistles, echolocation clicks, 
+#'   and burst pulses. Marine Mammal Science 33:520-540. doi:10.1111/mms.12381
+#' 
 #' @examples
 #' data(train.data)
 #' # initialize BANTER model with event data
@@ -31,17 +37,17 @@ plotDetectorTrace <- function(x, detector = NULL) {
   }
   
   traces <- lapply(detector, function(d) {
-    tr <- rfPermute::plotRFtrace(getBanterModel(x, d), FALSE)
+    tr <- rfPermute::plotTrace(getBanterModel(x, d), FALSE)
     tr + 
+      ggplot2::ylim(c(0, 1)) +
       ggplot2::ggtitle(d) +
       ggplot2::theme(axis.title = ggplot2::element_blank())
   })
   traces$ncol <- 1
-  traces$bottom <- "trees"
-  traces$left = "error"
+  traces$bottom <- "Trees"
+  traces$left = "Error"
   
-  p <- do.call(gridExtra::grid.arrange, traces)
-  print(p)
+  do.call(gridExtra::grid.arrange, traces)
   
   invisible(NULL)
 }
\ No newline at end of file
